==> xlt-7.3.0-sources.jar: org/htmlunit/javascript/host/media/OfflineAudioContext.java <==
/*
 * Copyright (c) 2002-2023 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.htmlunit.javascript.host.media;

import static org.htmlunit.javascript.configuration.SupportedBrowser.CHROME;
import static org.htmlunit.javascript.configuration.SupportedBrowser.EDGE;
import static org.htmlunit.javascript.configuration.SupportedBrowser.FF;
import static org.htmlunit.javascript.configuration.SupportedBrowser.FF_ESR;

import org.htmlunit.javascript.configuration.JsxClass;
import org.htmlunit.javascript.configuration.JsxConstructor;
import org.htmlunit.javascript.configuration.JsxFunction;

import org.htmlunit.corejs.javascript.Context;
import org.htmlunit.corejs.javascript.ScriptableObject;

/**
 * A JavaScript object for {@code OfflineAudioContext}.
 *
 * @author Ahmed Ashour
 * @author Ronald Brill
 */
@JsxClass({CHROME, EDGE, FF, FF_ESR})
public class OfflineAudioContext extends BaseAudioContext {

    /**
     * Creates an instance.
     */
    public OfflineAudioContext() {
    }

    /**
     * Creates an instance.
     * @param optionsOrNumberOfChannels the input
     */
    @JsxConstructor
    public void jsConstructor(final ScriptableObject optionsOrNumberOfChannels) {
        if (optionsOrNumberOfChannels == null) {
            throw Context.reportRuntimeError("Illegal constructor.");
        }
    }

    /**
     * @see <a href="https://developer.mozilla.org/en-US/docs/Web/API/OfflineAudioContext/startRendering">
     * MDN OfflineAudioContext#startRendering</a>
     */
    @JsxFunction
    public void startRendering() {
        // only a dummy
    }
}

==> xlt-8.1.0-sources.jar: org/htmlunit/javascript/host/media/OfflineAudioContext.java <==
/*
 * Copyright (c) 2002-2024 Gargoyle Software Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.htmlunit.javascript.host.media;

import static org.htmlunit.javascript.configuration.SupportedBrowser.CHROME;
import static org.htmlunit.javascript.configuration.SupportedBrowser.EDGE;
import static org.htmlunit.javascript.configuration.SupportedBrowser.FF;
import static org.htmlunit.javascript.configuration.SupportedBrowser.FF_ESR;

import org.htmlunit.corejs.javascript.ScriptableObject;
import org.htmlunit.javascript.JavaScriptEngine;
import org.htmlunit.javascript.configuration.JsxClass;
import org.htmlunit.javascript.configuration.JsxConstructor;
import org.htmlunit.javascript.configuration.JsxFunction;

/**
 * A JavaScript object for {@code OfflineAudioContext}.
 *
 * @author Ahmed Ashour
 * @author Ronald Brill
 */
@JsxClass({CHROME, EDGE, FF, FF_ESR})
public class OfflineAudioContext extends BaseAudioContext {

    /**
     * Creates an instance.
     */
    public OfflineAudioContext() {
    }

    /**
     * Creates an instance.
     * @param optionsOrNumberOfChannels the input
     */
    @JsxConstructor
    public void jsConstructor(final ScriptableObject optionsOrNumberOfChannels) {
        if (optionsOrNumberOfChannels == null) {
            throw JavaScriptEngine.reportRuntimeError("Illegal constructor.");
        }
    }

    /**
     * @see <a href="https://developer.mozilla.org/en-US/docs/Web/API/OfflineAudioContext/startRendering">
     * MDN OfflineAudioContext#startRendering</a>
     */
    @JsxFunction
    public void startRendering() {
        // only a dummy
    }
}
